@@ -2,10 +2,10 @@
 #
 # Module  : Relationship.pm
 # Purpose : Relationship in the Ontology.
-# License : Copyright (c) 2006, 2007, 2008 Erick Antezana. All rights reserved.
+# License : Copyright (c) 2006, 2007, 2008, 2009, 2010 Erick Antezana. All rights reserved.
 #           This program is free software; you can redistribute it and/or
 #           modify it under the same terms as Perl itself.
-# Contact : Erick Antezana <erant@psb.ugent.be>
+# Contact : Erick Antezana <erick.antezana@gmail.com>
 #
 package OBO::Core::Relationship;
 
@@ -87,11 +87,11 @@ a type (e.g. "is_a") and it must known the linking terms (tail and head).
 
 =head1 AUTHOR
 
-Erick Antezana, E<lt>erant@psb.ugent.beE<gt>
+Erick Antezana, E<lt>erick.antezana@gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006, 2007, 2008 by Erick Antezana
+Copyright (C) 2006, 2007, 2008, 2009, 2010 by Erick Antezana
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.7 or,
