@@ -11,7 +11,7 @@
 #           This program is free software; you can redistribute it and/or
 #           modify it under the same terms as Perl itself.
 #
-# Contact : Erick Antezana <erant@psb.ugent.be>
+# Contact : Erick Antezana <erick.antezana@gmail.com>
 #
 ##############################################################################
 
@@ -25,11 +25,11 @@ Generates a simple RDF graph from a given GOA file.
 
 =head1 AUTHOR
 
-Erick Antezana, E<lt>erant@psb.ugent.beE<gt>
+Erick Antezana, E<lt>erick.antezana@gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008 by Erick Antezana
+Copyright (C) 2008, 2009, 2010 by Erick Antezana
 
 This script is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.7 or,
@@ -41,10 +41,6 @@ use Carp;
 use strict;
 use warnings;
 
-BEGIN {
-	push @INC, '/group/biocomp/cbd/users/erant/workspace/ONTO-PERL'; # for testing
-}
-
 use OBO::CCO::GoaToRDF;
 
 my $input_file = shift(@ARGV);
