@@ -4,12 +4,12 @@
 #
 # Purpose : Converts a file from OBO to RDF.
 #
-# Usage: /usr/bin/perl -w obo2rdf.pl my_ontology.obo > my_ontology.rdf
+# Usage: /usr/bin/perl -w obo2rdf.pl my_ontology.obo "http://www.mydomain.com/ontology/rdf/" > my_ontology.rdf
 #
-# License : Copyright (c) 2006, 2007, 2008 Erick Antezana. All rights reserved.
+# License : Copyright (c) 2006, 2007, 2008, 2009, 2010 Erick Antezana. All rights reserved.
 #           This program is free software; you can redistribute it and/or
 #           modify it under the same terms as Perl itself.
-# Contact : Erick Antezana <erant@psb.ugent.be>
+# Contact : Erick Antezana <erick.antezana@gmail.com>
 #
 ##############################################################################
 
@@ -23,11 +23,11 @@ This script transforms an OBO file into RDF.
 
 =head1 AUTHOR
 
-Erick Antezana, E<lt>erant@psb.ugent.beE<gt>
+Erick Antezana, E<lt>erick.antezana@gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006, 2007, 2008 by Erick Antezana
+Copyright (C) 2006, 2007, 2008, 2009, 2010 by Erick Antezana
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.7 or,
@@ -39,12 +39,9 @@ use Carp;
 use strict;
 use warnings;
 
-BEGIN {
-	push @INC, '/group/biocomp/cbd/users/erant/workspace/ONTO-PERL'; # for testing
-}
-
 use OBO::Parser::OBOParser;
 
 my $my_parser = OBO::Parser::OBOParser->new();
-my $ontology = $my_parser->work(shift(@ARGV));
-$ontology->export(\*STDOUT, "rdf");
\ No newline at end of file
+my $ontology  = $my_parser->work(shift);
+my $url       = shift;
+$ontology->export(\*STDOUT, "rdf", $url);
