@@ -3,10 +3,10 @@
 # Module  : owl2obo.pl
 # Purpose : Converts a file from OWL to OBO.
 # Usage: /usr/bin/perl -w owl2obo.pl my_ontology.owl > my_ontology.obo
-# License : Copyright (c) 2006, 2007, 2008 Erick Antezana. All rights reserved.
+# License : Copyright (c) 2006, 2007, 2008, 2009, 2010 Erick Antezana. All rights reserved.
 #           This program is free software; you can redistribute it and/or
 #           modify it under the same terms as Perl itself.
-# Contact : Erick Antezana <erant@psb.ugent.be>
+# Contact : Erick Antezana <erick.antezana@gmail.com>
 #
 
 =head1 NAME
@@ -20,11 +20,11 @@ Use the obo2owl.pl to get the round-trip transformation.
 
 =head1 AUTHOR
 
-Erick Antezana, E<lt>erant@psb.ugent.beE<gt>
+Erick Antezana, E<lt>erick.antezana@gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006, 2007, 2008 by Erick Antezana
+Copyright (C) 2006, 2007, 2008, 2009, 2010 by Erick Antezana
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.7 or,
@@ -36,12 +36,8 @@ use Carp;
 use strict;
 use warnings;
 
-BEGIN {
-	push @INC, '/group/biocomp/cbd/users/erant/workspace/ONTO-PERL'; # for testing
-}
-
 use OBO::Parser::OWLParser;
 
 my $my_parser = OBO::Parser::OWLParser->new();
 my $ontology = $my_parser->work(shift(@ARGV));
-$ontology->export(\*STDOUT, "obo");
\ No newline at end of file
+$ontology->export(\*STDOUT, "obo");
